@@ -48,4 +48,15 @@ class MedicalCertificateDTO(BaseModel):
     
     
     doctor_name: Optional[str] = None
-    doctor_ruc: Optional[str] = None
\ No newline at end of file
+    doctor_ruc: Optional[str] = None
+
+
+class DiagnosisDTO(BaseModel):
+    name_diagnosis: str
+    cie_10_code: Optional[str] = None
+
+class MedicalDiagnosesDTO(BaseModel):
+    diagnoses: List[DiagnosisDTO]
+
+    class Config:
+        from_attributes = True
\ No newline at end of file
