@@ -7,6 +7,7 @@ from healthdatalayer.models import Client
 
 if TYPE_CHECKING:
     from healthdatalayer.models import ClientLab
+    from healthdatalayer.models import PathologicalHistory
     
 
 class Px(Client, table=True):
@@ -27,4 +28,8 @@ Px.profession = Relationship()
 Px.education = Relationship()
 Px.user = Relationship()
 Px.nationality = Relationship()
-Px.medical_labs = Relationship(back_populates="pxs", link_model="ClientLab")
\ No newline at end of file
+Px.medical_labs = Relationship(back_populates="pxs", link_model="ClientLab")
+Px.pathological_histories = Relationship(
+        back_populates="client",
+        link_model="PathologicalHistory"
+    )
\ No newline at end of file
