@@ -57,6 +57,12 @@ class PxRepository:
                     from healthdatalayer.models.client.nationality import Nationality
                     user_obj = session.get(Nationality, px.nationality_id)
                     object.__setattr__(px, 'nationality', user_obj)
+                    
+                from healthdatalayer.models.client.pathological_history import PathologicalHistory
+                statement = select(PathologicalHistory).where(PathologicalHistory.client_id == px_id)
+                pathological_his = session.exec(statement).all()
+                if pathological_his:
+                    object.__setattr__(px, 'pathological_histories',pathological_his)
             
             return px
             
@@ -100,6 +106,13 @@ class PxRepository:
                     from healthdatalayer.models.client.nationality import Nationality
                     user_obj = session.get(Nationality, px.nationality_id)
                     object.__setattr__(px, 'nationality', user_obj)
+                
+                    
+                from healthdatalayer.models.client.pathological_history import PathologicalHistory
+                statement = select(PathologicalHistory).where(PathologicalHistory.client_id == px.client_id)
+                pathological_his = session.exec(statement).all()
+                if pathological_his:
+                    object.__setattr__(px, 'pathological_histories',pathological_his)
             
             
             return px
@@ -149,6 +162,12 @@ class PxRepository:
                         from healthdatalayer.models.client.nationality import Nationality
                         user_obj = session.get(Nationality, px.nationality_id)
                         object.__setattr__(px, 'nationality', user_obj)
+                    
+                    from healthdatalayer.models.client.pathological_history import PathologicalHistory
+                    statement = select(PathologicalHistory).where(PathologicalHistory.client_id == px.client_id)
+                    pathological_his = session.exec(statement).all()
+                    if pathological_his:
+                        object.__setattr__(px, 'pathological_histories',pathological_his)
                 
                 
             return results
@@ -198,6 +217,12 @@ class PxRepository:
                         from healthdatalayer.models.client.nationality import Nationality
                         user_obj = session.get(Nationality, px.nationality_id)
                         object.__setattr__(px, 'nationality', user_obj)
+                    
+                    from healthdatalayer.models.client.pathological_history import PathologicalHistory
+                    statement = select(PathologicalHistory).where(PathologicalHistory.client_id == px.client_id)
+                    pathological_his = session.exec(statement).all()
+                    if pathological_his:
+                        object.__setattr__(px, 'pathological_histories',pathological_his)
             
             
             return results
