@@ -96,7 +96,7 @@ class MedicalDiagnosisVisitRepository:
         
     def delete_command(self, medical_diagnosis_visit_id: UUID, soft_delete: bool = False)->None:
         with get_session(self.tenant) as session:
-            existing_medical_diagnosis_visit = session.get(MedicalVisit, medical_diagnosis_visit_id)
+            existing_medical_diagnosis_visit = session.get(MedicalDiagnosisVisit, medical_diagnosis_visit_id)
             if not existing_medical_diagnosis_visit:
                 raise ValueError(f"MedicalDiagnosisVisit with id {medical_diagnosis_visit_id} does not exist")
 
